[Git][NTPsec/ntpsec][master] Minor documentation updates. Carry through as2201 -> austron rename.

Eric S. Raymond gitlab at mg.gitlab.com
Fri Jul 1 12:57:37 UTC 2016


Eric S. Raymond pushed to branch master at NTPsec / ntpsec


Commits:
07cd3b2e by Eric S. Raymond at 2016-07-01T08:56:44-04:00
Minor documentation updates.  Carry through as2201 -> austron rename.

- - - - -


8 changed files:

- docs/driver_austron.txt
- docs/refclock.txt
- ntpd/refclock_austron.c
- ntpd/refclock_conf.c
- ports/winnt/vs2005/ntpd.vcproj
- ports/winnt/vs2008/ntpd/ntpd.vcproj
- ports/winnt/vs2013/ntpd/ntpd.vcxproj
- ports/winnt/vs2013/ntpd/ntpd.vcxproj.filters


Changes:

=====================================
docs/driver_austron.txt
=====================================
--- a/docs/driver_austron.txt
+++ b/docs/driver_austron.txt
@@ -37,8 +37,7 @@ and attributes are embedded in the driver source code; however, the
 collection process can be enabled or disabled using the flag4 flag. If
 set, collection is enabled; if not, which is the default, it is
 disabled. A comprehensive suite of data reduction and summary scripts is
-in the ./scripts/stats directory
-of the distribution.
+in the ./scripts/stats directory of the distribution.
 
 == Monitor Data ==
 
@@ -77,7 +76,7 @@ refclock austron
 For debugging:
 
 ----------------------------------------------------------------------------
-refclock austron flag 4 1
+refclock austron flag4 1  # Enable clock statistic recording
 ----------------------------------------------------------------------------
 
 == Author ==


=====================================
docs/refclock.txt
=====================================
--- a/docs/refclock.txt
+++ b/docs/refclock.txt
@@ -55,20 +55,20 @@ clock when the driver has not been compiled or the hardware port has
 not been appropriately configured results in a scalding remark to the
 system log file, but is otherwise non hazardous.
 
-Reference clocks are supported in the same way as ordinary NTP clients
+Reference clocks are supported in the same way as ordinary NTP servers
 and use the same filter, select, cluster and combine algorithms. The
-connection to the computer is device dependent, usually a serial port,
-parallel port or special bus peripheral, but some can work directly
-from an audio codec or sound card. The particular device is specified
-by adding a soft link from the name used by the driver to the
-particular device name.
-
-The +refclock+ command is used to configure a reference clock. Only the
-+mode+, +minpoll+, +maxpoll+, and +prefer+ options are supported for
-reference clocks, as described on the link:clockopt.html[Reference
-Clock Commands] page. The +prefer+ option can be useful to persuade
-the server to cherish a reference clock with somewhat more enthusiasm
-than other reference clocks or peers. It is further discussed on the
+connection to the computer is device dependent - usually a serial
+port, but some can work directly from an audio codec or sound
+card. The particular device is specified by adding a soft link from
+the name used by the driver to the particular device name.
+
+The +refclock+ command is used to configure a reference clock. The
+options resemble those of the +server+ directives, but +mode+,
++minpoll+, +maxpoll+, and +prefer+ options are supported for reference
+clocks, as described on the link:clockopt.html[Reference Clock
+Commands] page. The +prefer+ option can be useful to persuade the
+server to cherish a reference clock with somewhat more enthusiasm than
+other reference clocks or peers. It is further discussed on the
 link:prefer.html[Mitigation Rules and the +prefer+ Keyword] page. The
 +minpoll+ and +maxpoll+ options have meaning only for selected clock
 drivers.
@@ -178,7 +178,7 @@ parse driver.
 |link:driver_truetime.html[truetime]    | D | TrueTime GPS/GOES Receivers
 |link:driver_irig.html[irig]            | D | IRIG Audio Decoder
 |link:driver_chu.html[chu]              | D | Radio CHU Audio Demodulator/Decoder
-|link:driver_generic.html[generic]      | TM| Generic Reference Driver (Parse)
+|link:driver_generic.html[generic]      | T | Generic Reference Driver (Parse)
 |link:driver_magnavox.html[magnavox]    | D | MX4200 and compatible GPS receivers
 |link:driver_austron.html[austron]      | D | Austron 2200A/2201A GPS Receivers
 |link:driver_arbiter.html[arbiter]      | D | Arbiter 1088A/B GPS Receiver
@@ -187,7 +187,7 @@ parse driver.
 |link:driver_pps.html[pps]              | T | PPS Clock Discipline
 |link:driver_hpgps.html[hpgps]          | T | Hewlett Packard GPS Receivers
 |link:driver_shm.html[shm]              | T | Shared Memory Driver
-|link:driver_palisade.html[palisade]    | TM| Trimble Palisade/Thunderbolt GPS
+|link:driver_palisade.html[palisade]    | T | Trimble Palisade/Thunderbolt GPS
 |link:driver_oncore.html[oncore]        | - | Motorola UT Oncore GPS
 |link:driver_jupiter.html[jupiter]      | D | Rockwell Jupiter GPS
 |link:driver_dumbclock.html[dumbclock]  | D | Dumb Clock
@@ -207,7 +207,6 @@ The flags field should be interpreted as follows:
 |Flag| Meaning
 | D | Deprecated.  May be removed in a future release
 | T | Regularly tested by an active maintainer (some devices/modes)
-| M | The driver supports multiple devices or major modes
 |====================================================================
 
 '''''


=====================================
ntpd/refclock_austron.c
=====================================
--- a/ntpd/refclock_conf.c
+++ b/ntpd/refclock_conf.c
@@ -49,7 +49,7 @@ extern	struct refclock	refclock_magnavox;
 #endif
 
 #ifdef CLOCK_AUSTRON
-extern	struct refclock	refclock_as2201;
+extern	struct refclock	refclock_austron;
 #else
 #define	refclock_as2201	refclock_none
 #endif
@@ -151,9 +151,12 @@ extern struct refclock refclock_gpsdjson;
 #endif
 
 /*
- * The symbols in the comments are no longer defined, except for REFCLK_ATOM_PPS.
- * If you compact or reorder this table, legacy ntpq instances that think they
- * can deduce driver types from address fields will get them wrong.
+ * This is the only place in the code that knows about the mapping between
+ * old-style numeric driver types and the drivers.
+ *
+ * The symbols in the comments are no longer defined. If you compact or
+ * reorder this table, legacy ntpq instances that think they can
+ * deduce driver types from address fields will get them wrong.
  */
 struct refclock * const refclock_conf[] = {
 	&refclock_none,		/* 0 REFCLK_NONE */
@@ -166,7 +169,7 @@ struct refclock * const refclock_conf[] = {
 	&refclock_chu,		/* 7 REFCLK_CHU_AUDIO */
 	&refclock_parse,	/* 8 REFCLK_GENERIC */
 	&refclock_magnavox,	/* 9 REFCLK_GPS_MX4200 */
-	&refclock_as2201,	/* 10 REFCLK_GPS_AS2201 */
+	&refclock_austron,	/* 10 REFCLK_GPS_AS2201 */
 	&refclock_arbiter,	/* 11 REFCLK_GPS_ARBITER */
 	&refclock_none,		/* 12 was: REFCLK_IRIG_TPRO */
 	&refclock_none,		/* 13 was: REFCLK_ATOM_LEITCH */


=====================================
ports/winnt/vs2005/ntpd.vcproj
=====================================
--- a/ports/winnt/vs2005/ntpd.vcproj
+++ b/ports/winnt/vs2005/ntpd.vcproj
@@ -1043,7 +1043,7 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\..\ntpd\refclock_as2201.c"
+				RelativePath="..\..\..\ntpd\refclock_austron.c"
 				>
 				<FileConfiguration
 					Name="Release|Win32"


=====================================
ports/winnt/vs2008/ntpd/ntpd.vcproj
=====================================
--- a/ports/winnt/vs2008/ntpd/ntpd.vcproj
+++ b/ports/winnt/vs2008/ntpd/ntpd.vcproj
@@ -770,7 +770,7 @@
 				>
 			</File>
 			<File
-				RelativePath="..\..\..\..\ntpd\refclock_as2201.c"
+				RelativePath="..\..\..\..\ntpd\refclock_austron.c"
 				>
 			</File>
 			<File


=====================================
ports/winnt/vs2013/ntpd/ntpd.vcxproj
=====================================
--- a/ports/winnt/vs2013/ntpd/ntpd.vcxproj
+++ b/ports/winnt/vs2013/ntpd/ntpd.vcxproj
@@ -285,7 +285,7 @@
     <ClCompile Include="..\..\..\..\ntpd\refclock_acts.c" />
     <ClCompile Include="..\..\..\..\ntpd\refclock_arbiter.c" />
     <ClCompile Include="..\..\..\..\ntpd\refclock_arc.c" />
-    <ClCompile Include="..\..\..\..\ntpd\refclock_as2201.c" />
+    <ClCompile Include="..\..\..\..\ntpd\refclock_austron.c" />
     <ClCompile Include="..\..\..\..\ntpd\refclock_pps.c" />
     <ClCompile Include="..\..\..\..\ntpd\refclock_bancomm.c" />
     <ClCompile Include="..\..\..\..\ntpd\refclock_chronolog.c" />


=====================================
ports/winnt/vs2013/ntpd/ntpd.vcxproj.filters
=====================================
--- a/ports/winnt/vs2013/ntpd/ntpd.vcxproj.filters
+++ b/ports/winnt/vs2013/ntpd/ntpd.vcxproj.filters
@@ -108,7 +108,7 @@
     <ClCompile Include="..\..\..\..\ntpd\refclock_arc.c">
       <Filter>Reference Clock</Filter>
     </ClCompile>
-    <ClCompile Include="..\..\..\..\ntpd\refclock_as2201.c">
+    <ClCompile Include="..\..\..\..\ntpd\refclock_austron.c">
       <Filter>Reference Clock</Filter>
     </ClCompile>
     <ClCompile Include="..\..\..\..\ntpd\refclock_pps.c">



View it on GitLab: https://gitlab.com/NTPsec/ntpsec/commit/07cd3b2e4a61c5b212b6619a92f0cdbd06f23d34
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.ntpsec.org/pipermail/vc/attachments/20160701/187aabb8/attachment.html>


More information about the vc mailing list
--- a/ntpd/refclock_austron.c
+++ b/ntpd/refclock_austron.c
@@ -1,5 +1,5 @@
 /*
  * refclock_as2201 - clock driver for the Austron 2201A GPS
  *	Timing Receiver
  */
 
@@ -124,7 +124,7 @@ static	void	as2201_poll	(int, struct peer *);
 /*
  * Transfer vector
  */
-struct	refclock refclock_as2201 = {
+struct	refclock refclock_austron = {
 	NAME,			/* basename of driver */
 	as2201_start,		/* start up driver */
 	as2201_shutdown,	/* shut down driver */
@@ -1,5 +1,5 @@
 /*
- * refclock_as2201 - clock driver for the Austron 2201A GPS
+ * refclock_austron - clock driver for the Austron 2201A GPS
  *	Timing Receiver
  */


=====================================
ntpd/refclock_conf.c
=====================================